/*
gettheta.c Version 2.3.0
Copyright (C) 2001-2010  dondalah721@yahoo.com (Dondalah)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to:

	Free Software Foundation, Inc.
	59 Temple Place - Suite 330
	Boston, MA  02111-1307, USA.
*/

#include <math.h>

/* From Hugh Kenner */
/* Geodesic math and how to use it */
/* Berkeley: University of California Press, 1976 */
/* ISBN: 0-520-02924-0 */

/* Equation 12.8 */
/* This formula calculates the value of theta */
/* based on the positions of x, y, and z in the */
/* symmetry triangle of an icosahedron. */
/* This formula is used in a Class I calculation */
/* of a geodesic sphere */

/* The values of x, y, and z should first be */
/* obtained from the getx(x), gety(x,y) */
/* and getz(x,y,z,freq) functions. */

/* Values of x,y,z in a 2v icosacap triangle

   First  digit is x.
   Second digit is y.
   Third  digit is z.

                            0,0,2
                             /\
                           /   \
                         /      \
                       /         \
               0,1,1  ------------  1,0,1
                    / \          / \
                  /    \       /    \
                /       \    /       \
              /          \ /          \
             --------------------------
          0,2,0         1,1,0        2,0,0

*/

double gettheta(x,y,z)
double x,y,z;
   {
   double theta,sum,quot;
   sum = (x * x) + (y * y);
   quot = sqrt(sum) / z;
   theta = atan(quot);
   return(theta);
   } /* gettheta */
